#
#    Copyright (c) 2009 Tom Keffer <tkeffer@gmail.com>
#
#    See the file LICENSE.txt for your full rights.
#
"""Package weewx. A set of modules for supporting a weather station on a sqlite database.

"""

__version__="0.6.1"

launchtime_ts = 0

# Constants used to indicate a unit system:
IMPERIAL = 1
METRIC   = 2

#
# Define possible exceptions that could get thrown.
#
class WeeWxIOError(IOError):
    """Base class of exceptions thrown when encountering an I/O error with the console.
    
    """
class WakeupError(WeeWxIOError):
    """Exception thrown when unable to wake up the console
    
    """
    
class AckError(WeeWxIOError):
    """Exception thrown when unable to get an acknowledging <ACK> from the console.
    
    """
    
class CRCError(WeeWxIOError):
    """Exception thrown when unable to pass a CRC check.
    
    """
class RetriesExceeded(WeeWxIOError):
    """Exception thrown when max retries exceeded.
    
    """
class UnknownArchiveType(StandardError):
    """Exception thrown after reading an unrecognized archive type.
    
    """
class UnsupportedFeature(StandardError):
    """Exception thrown when attempting to access a feature that is not supported (yet).
    
    """
    
class ViolatedPrecondition(StandardError):
    """Exception thrown when a function is called with violated preconditions.
    
    """
    
    