#
#    Copyright (c) 2009 Tom Keffer <tkeffer@gmail.com>
#
#    See the file LICENSE.txt for your full rights.
#

import os.path
import time
import syslog

import upload

class FtpData(object):
    """Synchronize local files with the web server"""

    def __init__(self, config_dict):
        # No FTP needed if the configuration dictionary
        # doesn't have an 'FTP' section: 
        if config_dict.has_key('FTP'):
            self.server   = config_dict['FTP']['server']
            self.user     = config_dict['FTP']['user']
            self.password = config_dict['FTP']['password']
            self.path     = config_dict['FTP']['path']
        else:
            self.server   = None
            self.user     = None
            self.password = None
            self.path     = None
        
        self.html_dir = os.path.join(config_dict['Station']['WEEWX_ROOT'],
                                     config_dict['HTML']['html_root'])

    def ftpData(self):
        """FTP the contents of the HTML directory to your web server. It uses
        module 'upload' to do the heavy lifting.
        """
        t1 = time.time()
    
        # While 'upload' is a nice simple utility, it assumes that the
        # root directory is the current directory. So, change directory to there:
        os.chdir(self.html_dir)
        
        # Now we can use the utility
        upstr = upload.Upstreamer(self.server, self.user, self.password, self.path)
        finder = upload.Finder()
        finder.find_all_files()
        try:
            n_uploaded = upstr.upstream(finder.get_new_files())
            finder.reset_stamp(time.time())
            finder.save()
            
            t2=time.time()
            syslog.syslog(syslog.LOG_INFO, 
                          "ftp: uploaded %d files to web server in %0.3f seconds" % (n_uploaded, (t2-t1)))
        except socket.error, e:
            syslog.syslog(syslog.LOG_ERR, "ftp: FTP failed. Reason: %s" % e)
    

    def run(self):
        self.ftpData()