#
#    Copyright (c) 2009 Tom Keffer <tkeffer@gmail.com>
#
#    See the file LICENSE.txt for your full rights.
#
"""Defines the thread that will process the weather data after an archive interval."""

import threading
import weewx.ftpdata
import weewx.factory

class ProcessThread(threading.Thread):
    """This thread creates an instance stationData to hold common data,
    then instantiates an object to do file processing, and one to do
    image processing. It also instantiates an object to FTP the contents
    of the HTML directory to a web server."""
    def __init__(self, config_dict):
        threading.Thread.__init__(self)
        # This will allow the program to exit even if this thread is running:
        self.setDaemon(True)
        stationData    = weewx.factory.dataFactory(config_dict)
        self.genFiles  = weewx.factory.genFilesFactory(config_dict,  stationData)
        self.genImages = weewx.factory.genImagesFactory(config_dict, stationData)
        self.ftpData   = weewx.factory.ftpFactory(config_dict)
        
    def run(self):
        self.genFiles.run()
        self.genImages.run()
        self.ftpData.run()